@@ -1,6 +1,6 @@
 
 # Copyright (C) 2012 - 2022  JJ Allaire, Dirk Eddelbuettel and Romain Francois
-# Copyright (C) 2023 - 2024  JJ Allaire, Dirk Eddelbuettel, Romain Francois and Iñaki Ucar
+# Copyright (C) 2023 - 2026  JJ Allaire, Dirk Eddelbuettel, Romain Francois and Iñaki Ucar
 #
 # This file is part of Rcpp.
 #
@@ -499,21 +499,11 @@ compileAttributes <- function(pkgdir = ".", verbose = getOption("verbose")) {
 
 # built-in C++98 plugin
 .plugins[["cpp98"]] <- function() {
-    if (getRversion() >= "3.4")         # with recent R versions, R can decide
-        list(env = list(USE_CXX98 = "yes"))
-    else
-        list(env = list(PKG_CXXFLAGS ="-std=c++98"))
+    list(env = list(USE_CXX98 = "yes"))
 }
                                         # built-in C++11 plugin
 .plugins[["cpp11"]] <- function() {
-    if (getRversion() >= "3.4")         # with recent R versions, R can decide
-        list(env = list(USE_CXX11 = "yes"))
-    else if (getRversion() >= "3.1")    # with recent R versions, R can decide
-        list(env = list(USE_CXX1X = "yes"))
-    else if (.Platform$OS.type == "windows")
-        list(env = list(PKG_CXXFLAGS = "-std=c++0x"))
-    else                                # g++-4.8.1 or later
-        list(env = list(PKG_CXXFLAGS ="-std=c++11"))
+    list(env = list(USE_CXX11 = "yes"))
 }
 
 # built-in C++11 plugin for older g++ compiler
@@ -525,10 +515,7 @@ compileAttributes <- function(pkgdir = ".", verbose = getOption("verbose")) {
 ## this is the default in g++-6.1 and later
 ## per https://gcc.gnu.org/projects/cxx-status.html#cxx14
 .plugins[["cpp14"]] <- function() {
-    if (getRversion() >= "3.4")         # with recent R versions, R can decide
-        list(env = list(USE_CXX14 = "yes"))
-    else
-        list(env = list(PKG_CXXFLAGS ="-std=c++14"))
+    list(env = list(USE_CXX14 = "yes"))
 }
 
 # built-in C++1y plugin for C++14 and C++17 standard under development
@@ -538,10 +525,7 @@ compileAttributes <- function(pkgdir = ".", verbose = getOption("verbose")) {
 
 # built-in C++17 plugin for C++17 standard (g++-6 or later)
 .plugins[["cpp17"]] <- function() {
-    if (getRversion() >= "3.4")         # with recent R versions, R can decide
-        list(env = list(USE_CXX17 = "yes"))
-    else
-        list(env = list(PKG_CXXFLAGS ="-std=c++17"))
+    list(env = list(USE_CXX17 = "yes"))
 }
 
 # built-in C++20 plugin for C++20
@@ -586,10 +570,74 @@ compileAttributes <- function(pkgdir = ".", verbose = getOption("verbose")) {
     list(env = list(PKG_CXXFLAGS ="-std=c++2b"))
 }
 
+.openmpPluginDefault <- function() {
+    list(env = list(PKG_CXXFLAGS = "-fopenmp", PKG_LIBS = "-fopenmp"))			# #nocov start
+}
+
+.openmpPluginDarwin <- function() {
+
+    # generate a test script for compilation
+    script <- tempfile("openmp-detect-", fileext = ".cpp")
+    writeLines("", con = script)
+    on.exit(unlink(script, force = TRUE), add = TRUE)
+
+    # get the C++ compiler from R
+    r <- file.path(R.home("bin"), "R")
+    output <- tryCatch(
+        system2(r, c("CMD", "SHLIB", "--dry-run", shQuote(script)), stdout = TRUE),
+        condition = identity
+    )
+    if (inherits(output, "condition"))
+        return(.openmpPluginDefault())
+
+    # extract the compiler invocation from the shlib output
+    # use some heuristics here...
+    index <- grep("make would use", output)
+    compile <- output[[index + 1L]]
+
+    # use everything up to the first include flag, which is normally
+    # the R headers from CPPFLAGS
+    idx <- regexpr(" -I", compile, fixed = TRUE)
+    cxx <- substring(compile, 1L, idx - 1L)
+
+    # check the compiler version
+    command <- paste(cxx, "--version")
+    version <- tryCatch(
+        system(command, intern = TRUE),
+        condition = identity
+    )
+    if (inherits(version, "condition"))
+        return(.openmpPluginDefault())
+
+    # if we're using Apple clang, use alternate flags
+    # assume libomp was installed following https://mac.r-project.org/openmp/
+    if (any(grepl("Apple clang", version))) {
+        cxxflags <- "-Xclang -fopenmp"
+        libs <- "-lomp"
+    }
+
+    # if we're using Homebrew clang, add in libomp include paths
+    else if (any(grepl("Homebrew clang", version))) {
+        machine <- Sys.info()[["machine"]]
+        prefix <- if (machine == "arm64") "/opt/homebrew" else "/usr/local"
+        cxxflags <- sprintf("-I%s/opt/libomp/include -fopenmp", prefix)
+        libs <- sprintf("-L%s/opt/libomp/lib -fopenmp", prefix)
+
+    # otherwise, use default -fopenmp flags for other compilers (LLVM clang; gcc)
+    } else {
+        cxxflags <- "-fopenmp"
+        libs <- "-fopenmp"
+    }
+
+    list(env = list(PKG_CXXFLAGS = cxxflags, PKG_LIBS = libs))				# #nocov end
+
+}
+
 ## built-in OpenMP plugin
-.plugins[["openmp"]] <- function() {
-    list(env = list(PKG_CXXFLAGS="-fopenmp",
-                    PKG_LIBS="-fopenmp"))
+.plugins[["openmp"]] <- if (Sys.info()[["sysname"]] == "Darwin") {
+    .openmpPluginDarwin
+} else {
+    .openmpPluginDefault
 }
 
 .plugins[["unwindProtect"]] <- function() { # nocov start
@@ -1239,41 +1287,39 @@ sourceCppFunction <- function(func, isVoid, dll, symbol) {
     declarations = character()
     call_entries = character()
 
-    # if we are running R 3.4 or higher we can use an internal utility function
+    # we are running R 3.4 or higher so we can use an internal utility function
     # to automatically discover additional native routines that require registration
-    if (getRversion() >= "3.4") {
 
-        # determine the package directory
-        pkgdir <- dirname(dirname(targetFile))
+    # determine the package directory
+    pkgdir <- dirname(dirname(targetFile))
 
-        # get the generated code from R
-        con <- textConnection(object = NULL, open = "w")
-        on.exit(close(con), add = TRUE)
-        tools::package_native_routine_registration_skeleton(
-            dir = pkgdir,
-            con = con,
-            character_only = FALSE
-        )
-        code <- textConnectionValue(con)
+    # get the generated code from R
+    con <- textConnection(object = NULL, open = "w")
+    on.exit(close(con), add = TRUE)
+    tools::package_native_routine_registration_skeleton(
+        dir = pkgdir,
+        con = con,
+        character_only = FALSE
+    )
+    code <- textConnectionValue(con)
 
-        # look for lines containing call entries
-        matches <- regexec('^\\s+\\{"([^"]+)",.*$', code)
-        matches <- regmatches(code, matches)
-        matches <- Filter(x = matches, function(x) {
-            length(x) > 0											# #nocov start
-        })
-        for (match in matches) {
-            routine <- match[[2]]
-            if (!routine %in% routines) {
-                declaration <- grep(sprintf("^extern .* %s\\(.*$", routine), code,
-                                    value = TRUE)
-                # FIXME: maybe we should extend this to *any* routine?
-                # or is there any case in which `void *` is not SEXP for a .Call?
-                if (routine == "run_testthat_tests")
-                    declaration <- gsub("void *", "SEXP", declaration, fixed=TRUE)
-                declarations <- c(declarations, sub("^extern", "RcppExport", declaration))
-                call_entries <- c(call_entries, match[[1]])			# #nocov end
-            }
+    # look for lines containing call entries
+    matches <- regexec('^\\s+\\{"([^"]+)",.*$', code)
+    matches <- regmatches(code, matches)
+    matches <- Filter(x = matches, function(x) {
+        length(x) > 0											# #nocov start
+    })
+    for (match in matches) {
+        routine <- match[[2]]
+        if (!routine %in% routines) {
+            declaration <- grep(sprintf("^extern .* %s\\(.*$", routine), code,
+                                value = TRUE)
+            # FIXME: maybe we should extend this to *any* routine?
+            # or is there any case in which `void *` is not SEXP for a .Call?
+            if (routine == "run_testthat_tests")
+                declaration <- gsub("void *", "SEXP", declaration, fixed=TRUE)
+            declarations <- c(declarations, sub("^extern", "RcppExport", declaration))
+            call_entries <- c(call_entries, match[[1]])			# #nocov end
         }
     }
 
