@@ -1,4 +1,4 @@
-# Copyright (C) 2009 - 2025  Dirk Eddelbuettel and Romain Francois
+# Copyright (C) 2009 - 2026  Dirk Eddelbuettel and Romain Francois
 #
 # This file is part of Rcpp.
 #
@@ -93,7 +93,7 @@ Rcpp.package.skeleton <- function(name = "anRpackage", list = character(),
                                          email))
         fields_written <- c("Package", "Type", "Title", "Version", "Date",
                             "Authors@R", "Description", "License", "Imports", "LinkingTo")
-        if (!is.na(githubuser)) {
+        if (!is.na(githubuser)) {					# #nocov start
             x <- cbind(x, matrix("", 1, 1, dimnames=list("", "URL")))
             x[1, "URL"] <- paste0("https://github.com/", githubuser, "/", name)
             x <- cbind(x, matrix("", 1, 1, dimnames=list("", "BugReports")))
@@ -102,7 +102,7 @@ Rcpp.package.skeleton <- function(name = "anRpackage", list = character(),
             fields_written <- c("Package", "Type", "Title", "Version", "Date",
                                 "Authors@R", "Description", "URL", "BugReports",
                                 "License", "Imports", "LinkingTo")
-            }
+            }										# #nocov end
 
         x[, "License"] <- license
         x[, "Title"] <- "Concise Summary of What the Package Does"
@@ -118,11 +118,7 @@ Rcpp.package.skeleton <- function(name = "anRpackage", list = character(),
     lines <- readLines(NAMESPACE)
     ns <- file(NAMESPACE, open="w")
     if (!any(grepl("useDynLib", lines))) {
-        if (getRversion() >= "3.4.0") {
-            lines <- c(sprintf( "useDynLib(%s, .registration=TRUE)", name), lines)
-        } else {
-            lines <- c(sprintf( "useDynLib(%s)", name), lines)				# #nocov
-        }
+        lines <- c(sprintf( "useDynLib(%s, .registration=TRUE)", name), lines)
         writeLines(lines, con = ns)
         message(" >> added useDynLib directive to NAMESPACE" )
     }
@@ -140,7 +136,7 @@ Rcpp.package.skeleton <- function(name = "anRpackage", list = character(),
 
     ## update the package description help page
     if (havePkgKitten) {                # if pkgKitten is available, use it
-        pkgKitten::playWithPerPackageHelpPage(name, path, maintainer, email)
+        pkgKitten::playWithPerPackageHelpPage(name, path, maintainer, email) # #nocov
     } else {
         .playWithPerPackageHelpPage(name, path, maintainer, email)			# #nocov
     }
@@ -202,14 +198,10 @@ Rcpp.package.skeleton <- function(name = "anRpackage", list = character(),
     # generate native routines if we aren't using attributes (which already generate
     # them automatically) and we have at least R 3.4
     if (!attributes) {
-        if (getRversion() >= "3.4.0") {
-            con <- file(file.path(src, "init.c"), "wt")
-            tools::package_native_routine_registration_skeleton(root, con=con)
-            close(con)
-            message(" >> created init.c for package registration")
-        } else {
-            message(" >> R version older than 3.4.0 detected, so NO file init.c created.")	# #nocov
-        }
+        con <- file(file.path(src, "init.c"), "wt")
+        tools::package_native_routine_registration_skeleton(root, con=con)
+        close(con)
+        message(" >> created init.c for package registration")
     }
 
     lines <- readLines(package.doc <- file.path( root, "man", sprintf("%s-package.Rd", name)))
