@@ -1,4 +1,4 @@
-#!/usr/bin/r
+#!/usr/bin/env r
 
 ## this short example was provided in response to this StackOverflow questions:
 ## http://stackoverflow.com/questions/6807068/why-is-my-recursive-function-so-slow-in-r
@@ -6,6 +6,8 @@
 ## all expensive in C++ (my machine sees a 700-fold speed increase) and c) the byte
 ## compiler in R does not help here.
 
+suppressMessages(library(Rcpp))
+
 ## byte compiler
 require(compiler)
 
