@@ -1,7 +1,7 @@
 
 // class.h: Rcpp R/C++ interface class library -- Rcpp modules
 //
-// Copyright (C) 2012 - 2013 Dirk Eddelbuettel and Romain Francois
+// Copyright (C) 2012 - 2025 Dirk Eddelbuettel and Romain Francois
 //
 // This file is part of Rcpp.
 //
@@ -110,21 +110,16 @@
             return constructor( docstring, valid ) ;
         }
 
-#if defined(HAS_VARIADIC_TEMPLATES)
-    template <typename... T>
-    self& constructor( const char* docstring = 0, ValidConstructor valid = &yes_arity<sizeof...(T)> ){
-        AddConstructor( new Constructor<Class,T...> , valid, docstring ) ;
-        return *this ;
-    }
-    template <typename... T>
-    self& factory( Class* (*fun)(T...), const char* docstring = 0, ValidConstructor valid = &yes_arity<sizeof...(T)> ){
-        AddFactory( new Factory<Class,T...>(fun) , valid, docstring ) ;
-        return *this ;
-    }
-#else
-    #include <Rcpp/module/Module_generated_class_constructor.h>
-    #include <Rcpp/module/Module_generated_class_factory.h>
-#endif
+        template <typename... T>
+        self& constructor( const char* docstring = 0, ValidConstructor valid = &yes_arity<sizeof...(T)> ){
+            AddConstructor( new Constructor<Class,T...> , valid, docstring ) ;
+            return *this ;
+        }
+        template <typename... T>
+        self& factory( Class* (*fun)(T...), const char* docstring = 0, ValidConstructor valid = &yes_arity<sizeof...(T)> ){
+            AddFactory( new Factory<Class,T...>(fun) , valid, docstring ) ;
+            return *this ;
+        }
 
     public:
 
@@ -265,47 +260,42 @@
             return *this ;
         }
 
-#if defined(HAS_VARIADIC_TEMPLATES)
-    template <typename RESULT_TYPE, typename... T>
-    self& method(const char* name_, RESULT_TYPE (Class::*fun)(T...),
-                const char* docstring = 0, ValidMethod valid = &yes_arity<sizeof...(T)>) {
-        AddMethod( name_, new CppMethodN<Class,RESULT_TYPE,T...>(fun), valid, docstring);
-        return *this;
-    }
-    template <typename RESULT_TYPE, typename... T>
-    self& method(const char* name_, RESULT_TYPE (Class::*fun)(T...) const,
-                const char* docstring = 0, ValidMethod valid = &yes_arity<sizeof...(T)>) {
-        AddMethod( name_, new const_CppMethodN<Class,RESULT_TYPE,T...>(fun), valid, docstring);
-        return *this;
-    }
-    template <typename RESULT_TYPE, typename... T>
-    self& nonconst_method(const char* name_, RESULT_TYPE (Class::*fun)(T...),
-                const char* docstring = 0, ValidMethod valid = &yes_arity<sizeof...(T)>) {
-        AddMethod( name_, new CppMethodN<Class,RESULT_TYPE,T...>(fun), valid, docstring);
-        return *this;
-    }
-    template <typename RESULT_TYPE, typename... T>
-    self& const_method(const char* name_, RESULT_TYPE (Class::*fun)(T...) const,
-                const char* docstring = 0, ValidMethod valid = &yes_arity<sizeof...(T)>) {
-        AddMethod( name_, new const_CppMethodN<Class,RESULT_TYPE,T...>(fun), valid, docstring);
-        return *this;
-    }
-    template <typename RESULT_TYPE, typename... T>
-    self& method(const char* name_, RESULT_TYPE (*fun)(Class*, T...),
-                const char* docstring = 0, ValidMethod valid = &yes_arity<sizeof...(T)>) {
-        AddMethod( name_, new Pointer_CppMethodN<Class,RESULT_TYPE,T...>(fun), valid, docstring);
-        return *this;
-    }
-    template <typename RESULT_TYPE, typename... T>
-    self& const_method(const char* name_, RESULT_TYPE (*fun)(const Class*, T...),
-                const char* docstring = 0, ValidMethod valid = &yes_arity<sizeof...(T)>) {
-        AddMethod( name_, new Const_Pointer_CppMethodN<Class,RESULT_TYPE,T...>(fun), valid, docstring);
-        return *this;
-    }
-#else
-    #include <Rcpp/module/Module_generated_method.h>
-    #include <Rcpp/module/Module_generated_Pointer_method.h>
-#endif
+        template <typename RESULT_TYPE, typename... T>
+        self& method(const char* name_, RESULT_TYPE (Class::*fun)(T...),
+                     const char* docstring = 0, ValidMethod valid = &yes_arity<sizeof...(T)>) {
+            AddMethod( name_, new CppMethodN<Class,RESULT_TYPE,T...>(fun), valid, docstring);
+            return *this;
+        }
+        template <typename RESULT_TYPE, typename... T>
+        self& method(const char* name_, RESULT_TYPE (Class::*fun)(T...) const,
+                     const char* docstring = 0, ValidMethod valid = &yes_arity<sizeof...(T)>) {
+            AddMethod( name_, new const_CppMethodN<Class,RESULT_TYPE,T...>(fun), valid, docstring);
+            return *this;
+        }
+        template <typename RESULT_TYPE, typename... T>
+        self& nonconst_method(const char* name_, RESULT_TYPE (Class::*fun)(T...),
+                              const char* docstring = 0, ValidMethod valid = &yes_arity<sizeof...(T)>) {
+            AddMethod( name_, new CppMethodN<Class,RESULT_TYPE,T...>(fun), valid, docstring);
+            return *this;
+        }
+        template <typename RESULT_TYPE, typename... T>
+        self& const_method(const char* name_, RESULT_TYPE (Class::*fun)(T...) const,
+                           const char* docstring = 0, ValidMethod valid = &yes_arity<sizeof...(T)>) {
+            AddMethod( name_, new const_CppMethodN<Class,RESULT_TYPE,T...>(fun), valid, docstring);
+            return *this;
+        }
+        template <typename RESULT_TYPE, typename... T>
+        self& method(const char* name_, RESULT_TYPE (*fun)(Class*, T...),
+                     const char* docstring = 0, ValidMethod valid = &yes_arity<sizeof...(T)>) {
+            AddMethod( name_, new Pointer_CppMethodN<Class,RESULT_TYPE,T...>(fun), valid, docstring);
+            return *this;
+        }
+        template <typename RESULT_TYPE, typename... T>
+        self& const_method(const char* name_, RESULT_TYPE (*fun)(const Class*, T...),
+                           const char* docstring = 0, ValidMethod valid = &yes_arity<sizeof...(T)>) {
+            AddMethod( name_, new Const_Pointer_CppMethodN<Class,RESULT_TYPE,T...>(fun), valid, docstring);
+            return *this;
+        }
 
         bool has_method( const std::string& m){
             return vec_methods.find(m) != vec_methods.end() ;
