@@ -1,8 +1,8 @@
-// -*- mode: C++; c-indent-level: 4; c-basic-offset: 4; tab-width: 4 -*-
+// -*- mode: C++; c-indent-level: 4; c-basic-offset: 4; indent-tabs-mode: nil; -*-
 //
-// rwilcox.h: Rcpp R/C++ interface class library -- 
+// rwilcox.h: Rcpp R/C++ interface class library --
 //
-// Copyright (C) 2010 - 2011 Douglas Bates, Dirk Eddelbuettel and Romain Francois
+// Copyright (C) 2010 - 2016  Douglas Bates, Dirk Eddelbuettel and Romain Francois
 //
 // This file is part of Rcpp.
 //
@@ -23,14 +23,17 @@
 #define Rcpp__stats__random_rwilcox_h
 
 namespace Rcpp {
+namespace stats {
 
-	// Please make sure you to read Section 6.3 of "Writing R Extensions"
-	// about the need to call GetRNGstate() and PutRNGstate() when using 
-	// the random number generators provided by R.
-	inline NumericVector rwilcox( int n, double mm, double nn ){
-		return NumericVector( n, ::Rf_rwilcox, mm, nn ) ;
-	}
+class WilcoxGenerator : public Generator<double>{
+public:
+    WilcoxGenerator( double mm_, double nn_) : mm(mm_), nn(nn_){}
+    inline double operator()() const { return ::Rf_rwilcox(mm,nn); }
+private:
+    double mm, nn ;
+};
 
+} // stats
 } // Rcpp
 
 #endif
