@@ -412,20 +412,20 @@ namespace sugar{
 
 }
 
-template <int RTYPE,bool NA, typename T>
-inline sugar::Minus_Vector_Primitive< RTYPE , NA, T >
+template <int RTYPE,bool NA, typename T, typename U>
+inline typename traits::enable_if<traits::is_convertible<typename traits::remove_const_and_reference<U>::type, typename traits::storage_type<RTYPE>::type>::value, sugar::Minus_Vector_Primitive< RTYPE , NA, T > >::type
 operator-(
 	const VectorBase<RTYPE,NA,T>& lhs,
-	typename traits::storage_type<RTYPE>::type rhs
+	const U &rhs
 ) {
 	return sugar::Minus_Vector_Primitive<RTYPE,NA,T>( lhs, rhs ) ;
 }
 
 
-template <int RTYPE,bool NA, typename T>
-inline sugar::Minus_Primitive_Vector< RTYPE , NA,T>
+template <int RTYPE,bool NA, typename T, typename U>
+inline typename traits::enable_if<traits::is_convertible<typename traits::remove_const_and_reference<U>::type, typename traits::storage_type<RTYPE>::type>::value, sugar::Minus_Primitive_Vector< RTYPE , NA,T> >::type
 operator-(
-	typename traits::storage_type<RTYPE>::type lhs,
+	const U &lhs,
 	const VectorBase<RTYPE,NA,T>& rhs
 ) {
 	return sugar::Minus_Primitive_Vector<RTYPE,NA,T>( lhs, rhs ) ;
