@@ -107,7 +107,7 @@
 #undef pt
 #undef ptukey
 #undef punif
-#undef pythag
+/* #undef pythag */
 #undef pweibull
 #undef pwilcox
 #undef qbeta
@@ -146,7 +146,7 @@
 #undef rhyper
 #undef rlnorm
 #undef rlogis
-#undef rnbeta
+//#undef rnbeta
 #undef rnbinom
 #undef rnchisq
 #undef rnf
