@@ -3,7 +3,7 @@
 //
 // wrap_type_traits.h: Rcpp R/C++ interface class library -- traits to help wrap
 //
-// Copyright (C) 2010 - 2012 Dirk Eddelbuettel and Romain Francois
+// Copyright (C) 2010 - 2013 Dirk Eddelbuettel and Romain Francois
 //
 // This file is part of Rcpp.
 //
@@ -37,10 +37,10 @@ struct wrap_type_primitive_tag{};
 struct wrap_type_unknown_tag{};
 
 /**
- * module objects pointers (object<T>). conversion done using make_new_object<>() 
+ * module objects pointers (object<T>). conversion done using make_new_object<>()
  */
 struct wrap_type_module_object_pointer_tag{} ;
- 
+
 /**
  * declared module object type (by the RCPP_EXPOSED_CLASS macro)
  */
@@ -51,6 +51,11 @@ struct wrap_type_module_object_tag{} ;
  */
 struct wrap_type_enum_tag{} ;
 
+/**
+ * character arrays
+ */
+struct wrap_type_char_array{} ;
+
 /**
  * Type trait that helps the dispatch of wrap to the proper method
  *
@@ -62,6 +67,8 @@ struct wrap_type_enum_tag{} ;
  */
 template <typename T> struct wrap_type_traits { typedef wrap_type_unknown_tag wrap_category; } ;
 
+template <std::size_t N> struct wrap_type_traits<char[N]> { typedef wrap_type_char_array wrap_category; } ;
+template <std::size_t N> struct wrap_type_traits<const char[N]> { typedef wrap_type_char_array wrap_category; } ;
 /**
  * Total specialization for primitive types
  */
@@ -74,8 +81,13 @@ template <> struct wrap_type_traits<Rcomplex> { typedef wrap_type_primitive_tag
 template <> struct wrap_type_traits<unsigned int> { typedef wrap_type_primitive_tag wrap_category; } ;
 template <> struct wrap_type_traits<bool> { typedef wrap_type_primitive_tag wrap_category; } ;
 template <> struct wrap_type_traits<std::string> { typedef wrap_type_primitive_tag wrap_category; } ;
+template <> struct wrap_type_traits<std::wstring> { typedef wrap_type_primitive_tag wrap_category; } ;
+#if __cplusplus >= 201703L
+template <> struct wrap_type_traits<std::string_view> { typedef wrap_type_primitive_tag wrap_category; } ;
+#endif
 template <> struct wrap_type_traits<Rcpp::String> { typedef wrap_type_primitive_tag wrap_category; } ;
 template <> struct wrap_type_traits<char> { typedef wrap_type_primitive_tag wrap_category; } ;
+template <> struct wrap_type_traits<wchar_t> { typedef wrap_type_primitive_tag wrap_category; } ;
 
 template <> struct wrap_type_traits<float> { typedef wrap_type_primitive_tag wrap_category; } ;
 template <> struct wrap_type_traits< std::complex<float> > { typedef wrap_type_primitive_tag wrap_category; } ;
@@ -89,11 +101,6 @@ template <> struct wrap_type_traits<long double> { typedef wrap_type_primitive_t
 template <> struct wrap_type_traits<short> { typedef wrap_type_primitive_tag wrap_category; } ;
 template <> struct wrap_type_traits<unsigned short> { typedef wrap_type_primitive_tag wrap_category; } ;
 
-#ifdef RCPP_HAS_LONG_LONG_TYPES
-template <> struct wrap_type_traits<rcpp_long_long_type> { typedef wrap_type_primitive_tag wrap_category; } ;
-template <> struct wrap_type_traits<rcpp_ulong_long_type> { typedef wrap_type_primitive_tag wrap_category; } ;
-#endif
-
 template <typename T> struct wrap_type_traits< Rcpp::object<T> > { typedef wrap_type_module_object_pointer_tag wrap_category; } ;
 
 
